<div class="filter-group">
    <label class="filter-label">Django App</label>
    <select id="filter-app" class="filter-select">
        <option value="">All</option>
        <!-- Dynamically filled -->
    </select>
</div>

