<div class="filter-group">
    <label class="filter-label">Search Support</label>
    <select id="filter-search" class="filter-select">
        <option value="">All</option>
        <option value="true">Yes</option>
        <option value="false">No</option>
    </select>
</div>

