# {{ name }}

<!-- inject CSS directly -->
{% for stylesheet in stylesheets %}
<link rel="stylesheet" href="{{ stylesheet }}">
{% endfor %}

**App:** {{ app_label }}

**Table:** `{{ table_name }}`

## Description

{{ description }}

{% if fields %}
{% include "model_detail/fields.html" with fields=fields %}
{% endif %}

{% if has_choices %}
{% include "model_detail/choices.html" with fields=fields %}
{% endif %}

{% if relationships %}
{% include "model_detail/relationships.html" with relationships=relationships %}
{% endif %}

{% if methods %}
{% include "model_detail/methods.html" with methods=methods %}
{% endif %}

{% if meta_options %}
{% include "model_detail/meta.html" with meta_options=meta_options %}
{% endif %}
