<div class="filter-group">
    <label class="filter-label">HTTP Method</label>
    <select id="filter-method" class="filter-select">
        <option value="">All</option>
        <option value="get">GET</option>
        <option value="post">POST</option>
        <option value="put">PUT</option>
        <option value="patch">PATCH</option>
        <option value="delete">DELETE</option>
    </select>
</div>

