# API Endpoints

<style>
{% for stylesheet in stylesheets %}
@import url("{{ stylesheet|safe }}");
{% endfor %}
</style>

{% for script in scripts %}
<script src="{{ script|safe }}" defer></script>
{% endfor %}

<div class="main-content">
    {% include "endpoints/list/filter_section.html" %}
    {% for app_name, endpoints in endpoints_by_app.items %}
        <h2>{{ app_name|title }}</h2>
        <div class="endpoints-grid">
            {% for endpoint in endpoints %}
                {% include "endpoints/list/endpoint_card.html" %}
            {% endfor %}
        </div>
    {% endfor %}
</div>